/*
 * Copyright (c) 2007, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wso2.registry;

public interface CoreRegistry {
    /**
     * Returns the resource in the given path.
     *
     * @param path Path of the resource. e.g. /project1/server/deployment.xml
     * @return Resource instance
     * @throws org.wso2.registry.RegistryException
     *          is thrown if the resource is not in the registry
     */
    Resource get(String path) throws RegistryException;

    /**
     * Check whether a resource exist in the given path
     *
     * @param path Path of the resource to be checked
     * @return true if a resource exist in the given path, false otherwise.
     * @throws org.wso2.registry.RegistryException
     *          if an error occurs
     */
    boolean resourceExists(String path) throws RegistryException;

    /**
     * Adds or updates resources in the registry. If there is no resource in the given path,
     * resource is added. If a resource already exist in the given path, it will be replaced with
     * the new resource.
     *
     * @param suggestedPath the path which we'd like to use for the new resource.
     * @param resource      Resource instance for the new resource
     * @return the actual path that the server chose to use for our Resource
     * @throws org.wso2.registry.RegistryException
     *
     */
    String put(String suggestedPath, Resource resource) throws RegistryException;

    /**
     * Deletes the resource in the given path. If the path refers to a directory, all child
     * resources of the directory will also be deleted.
     *
     * @param path Path of the resource to be deleted.
     * @throws RegistryException is thrown depending on the implementation.
     */
    void delete(String path) throws RegistryException;
}
