/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.wso2.registry;

import java.sql.Timestamp;
import java.util.Date;
import java.util.Properties;

public class Resource {

    private long id;
    private String authorUserName;
    private Timestamp createdTime;
    private String lastUpdaterUserName;
    private Timestamp lastModified;
    private String description;
    private String path;
    private String mediaType;
    private String parentPath;

    /**
     * Used to detect whether the resource content is modified after it is retrieved from the
     * Registry. If this is set to true at the time of adding the resource back to the Registry, new
     * version will be created.
     */
    private boolean contentModified;

    /**
     * Normal resources have the state RegistryConstants.ACTIVE_STATE (100) Deleted resources have
     * the state RegistryConstants.DELETED_STATE (101)
     */
    private int state;

    private Properties properties;

    private String[] dependsOn;
    private String[] dependedOnBy;

    //To store any kind of object
    private Object content;

    private boolean directory = false;

    public Resource() {
        this.properties = new Properties();
    }

    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }

    public String getAuthorUserName() {
        return authorUserName;
    }

    public void setAuthorUserName(String authorUserName) {
        this.authorUserName = authorUserName;
    }

    public Date getCreatedTime() {
        return createdTime;
    }

    public void setCreatedTime(Date createdTime) {
        this.createdTime = new Timestamp(createdTime.getTime());
    }

    public Date getLastModified() {
        return lastModified;
    }

    public void setLastModified(Date lastModified) {
        this.lastModified = new Timestamp(lastModified.getTime());
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = preparePath(path);
    }

    public String getMediaType() {
        return mediaType;
    }

    public void setMediaType(String mediaType) {
        this.mediaType = mediaType;
    }

    public String getParentPath() {
        return parentPath;
    }

    public void setParentPath(String parentPath) {
        this.parentPath = parentPath;
    }

    public int getState() {
        return state;
    }

    public void setState(int state) {
        this.state = state;
    }

    public String getProperty(String key) {
        return (String)properties.get(key);
    }

    public Properties getProperties() {
        return properties;
    }

    public void setProperty(String key, String value) {
        this.properties.put(key, value);
    }

    public void setProperties(Properties properties) {
        this.properties = properties;
    }

    public Object getContent() {
        return content;
    }

    public void setContent(Object content) {
        this.content = content;
        this.contentModified = true;
    }

    private String preparePath(String path) {

        String preparedPath = path;

        // make sure that the path does not end with a "/"
        if (!path.equals(RegistryConstants.ROOT_PATH) &&
            path.endsWith(RegistryConstants.PATH_SEPARATOR)) {
            preparedPath =
                    path.substring(0, path.length() - RegistryConstants.PATH_SEPARATOR.length());
        }

        return preparedPath;
    }


    public String getLastUpdaterUserName() {
        return lastUpdaterUserName;
    }

    public void setLastUpdaterUserName(String lastUpdaterUserName) {
        this.lastUpdaterUserName = lastUpdaterUserName;
    }

    public boolean isDirectory() {
        return directory;
    }

    public void setDirectory(boolean directory) {
        this.directory = directory;
    }

    public String[] getDependedOnBy() {
        return dependedOnBy;
    }

    public void setDependedOnBy(String[] dependedOnBy) {
        this.dependedOnBy = dependedOnBy;
    }

    public String[] getDependsOn() {
        return dependsOn;
    }

    public void setDependsOn(String[] dependsOn) {
        this.dependsOn = dependsOn;
    }

    public boolean isContentModified() {
        return contentModified;
    }

    /**
     * This method is used to explicitly set the content modified state of the resource. Normal
     * users of the Registry API should not call this method.
     *
     * @param contentModified
     */
    public void setContentModified(boolean contentModified) {
        this.contentModified = contentModified;
    }
}
